locals {
  engine_type = "ActiveMQ"

  ## Ensures that we get a single subnet for SINGLE_INSTANCE deployments OR ONLY 2 subnets if more are provided.
  subnet_ids = var.deployment_mode == "SINGLE_INSTANCE" && length(var.subnet_ids) > 1 ? slice(var.subnet_ids, 0, 1) : length(var.subnet_ids) > 2 ? slice(var.subnet_ids, 0, 2) : var.subnet_ids
}

## Even though this Configuration is optional, AWS will still generate one if not supplied.
## So, it's mostly about whether one wants to define their own custom set of configurations.
resource "aws_mq_configuration" "custom" {
  count = var.config_data != null ? 1 : 0

  description    = "Custom Configuration for Amazon MQ Broker"
  name           = "${var.broker_name}_configuration"
  engine_type    = local.engine_type
  engine_version = var.engine_version
  tags           = var.tags
  data           = var.config_data
}

resource "aws_mq_broker" "default" {
  broker_name                = var.broker_name
  engine_type                = "ActiveMQ"
  engine_version             = var.engine_version
  host_instance_type         = var.instance_type
  security_groups            = var.security_group_ids
  subnet_ids                 = local.subnet_ids
  deployment_mode            = var.deployment_mode
  auto_minor_version_upgrade = false
  publicly_accessible        = false
  tags                       = var.tags

  dynamic "configuration" {
    for_each = (var.config_data != null) ? [true] : []
    content {
      id       = aws_mq_configuration.custom[0].id
      revision = aws_mq_configuration.custom[0].latest_revision
    }
  }

  user {
    username       = var.broker_username
    password       = var.broker_password
    console_access = true
  }

  encryption_options {
    use_aws_owned_key = false
  }
}