variable "broker_name" {
  type        = string
  description = "Name of the ActiveMQ Broker"
}

variable "broker_password" {
  type        = string
  description = "ActiveMQ Broker Password"
}

variable "broker_username" {
  type        = string
  description = "ActiveMQ Broker Username"
  default     = "cbadmin"
}

variable "config_data" {
  type        = string
  description = <<-EOT
  Broker configuration data. Enables custom implementations of supported Broker configurations.

  A default configuration is supplied.

  ActiveMQ:
  See https://docs.aws.amazon.com/amazon-mq/latest/developer-guide/amazon-mq-broker-configuration-parameters.html
  Note: XML format
  EOT
  default     = null
}

variable "deployment_mode" {
  type        = string
  description = "Deployment mode for the cluster. See https://registry.terraform.io/providers/hashicorp/aws/latest/docs/resources/mq_broker#deployment_mode"
  default     = "SINGLE_INSTANCE"

  validation {
    condition     = contains(["SINGLE_INSTANCE", "ACTIVE_STANDBY_MULTI_AZ", "CLUSTER_MULTI_AZ"], var.deployment_mode)
    error_message = "Valid values for 'deployment_mode' are: SINGLE_INSTANCE, ACTIVE_STANDBY_MULTI_AZ, and CLUSTER_MULTI_AZ."
  }
}

variable "engine_version" {
  type        = string
  description = <<-EOT
  ActiveMQ Broker Engine Version.
  See https://docs.aws.amazon.com/amazon-mq/latest/developer-guide/activemq-version-management.html
  EOT
  ## we don't want to maintain the active list of valid versions here, so we'll just let the SDK return encountered errors.
}

variable "instance_type" {
  type        = string
  description = <<-EOT
  ActiveMQ Broker Instance Type. See below for AWS documentation.
  See https://docs.aws.amazon.com/amazon-mq/latest/developer-guide/activemq-broker-instance-types.html
  EOT
  default     = "mq.t3.micro"
  ## similar to 'engine_version', we won't want to maintain the acceptable list of instance types.
}

variable "security_group_ids" {
  type = list(string)
  ## sic: these are provided by the env_definitions file
  description = "ActiveMQ Broker security groups"
  default     = []
}

variable "subnet_ids" {
  type = list(string)
  ## sic: these are provided by the env_definitions file
  description = "ActiveMQ Broker subnet IDs"
  default     = []
}

variable "tags" {
  type        = map(string)
  description = "Tags for SQS Queue"
}
